Trajectory Viewer

Choose a results.jsonl file to begin (and optional metadata.json). Each line should be a JSON object with keys like "prompt", "completion", "answer", "info", "task", "reward", "judge_reward", "format_reward".

### Metrics

Reward: -
Judge Reward: -
Format Reward Func: -
Avg Reward: -
Avg Judge Reward: -
Avg Format Reward Func: -

### Task

-

### Functions (from info)

### Prompts

System prompt (click to expand)
Initial user prompt

### Completions

tool call tool result assistant response

### Answer